==> hidrokit-0.3.6.tar.gz: hidrokit-0.3.6/CODE_OF_CONDUCT.md <==
# Kode Etik Contributor Covenant

## Janji Kami

Sesuai minat kami untuk membuat lingkungan yang terbuka dan ramah, kami sebagai kontributor dan pengelola berjanji untuk membuat partisipasi dalam proyek kami dan komunitas kami bebas dari pelecehan untuk semua orang, tanpa memandang usia, ukuran tubuh, disabilitas, kelompok etnis, identitas gender dan ekspresinya, tingkat pengalaman, pendidikan, status sosial ekonomi, kewarganegaraan, penampilan pribadi, ras, agama, atau identitas dan orientasi seksual.

## Standar Kami

Kejadian perilaku yang berkontribusi untuk menciptakan sebuah lingkungan yang positif meliputi:
* Memakai bahasa yang ramah dan inklusif.
* Menghormati sudut pandang dan pengalaman yang berbeda.
* Menerima kritik konstruktif dengan baik.
* Fokus terhadap apa yang terbaik bagi komunitas.
* Menunjukkan empati kepada anggota komunitas yang lain.

Contoh perilaku yang tidak dapat diterima oleh partisipan meliputi:
* Penggunaan bahasa atau citra seksual dan perhatian seksual yang tidak diinginkan.
* _Trolling_, komentar menghina, dan serangan terhadap individual atau pandangan politik.
* Pelecahan umum atau pribadi.
* Menerbitkan informasi pribadi orang lain, seperti alamat fisik atau elektronik, tanpa izin.
* Perilaku lain yang dapat dianggap tidak sesuai dalam lingkungan profesional.

## Tanggung Jawab Kami

Pengelola proyek bertanggung jawab untuk mengklarifikasi standar perilaku yang dapat diterima dan diharapkan untuk melakukan tindakan korektif yang tepat dan adil dalam menanggapi kasus perilaku yang tidak dapat diterima.

Pengelola proyek mempunyai hak dan tanggung jawab untuk menghapus, mengubah, atau menolak komentar, _commit_, kode, suntingan wiki, masalah, dan kontribusi lainnya yang tidak sesuai dengan Kode Etik ini, atau untuk melarang sementara atau secara permanen kontributor untuk perilaku lain yang mereka anggap tidak tepat, mengancam, menyinggung, atau berbahaya.

## Cakupan

Kode Etik ini berlaku baik di dalam proyek maupun di ruang publik ketika seseorang mewakili proyek atau komunitasnya. Contoh dari mewakili sebuah proyek atau komunitas termasuk menggunakan alamat email resmi proyek, posting melalui akun media sosial resmi, atau bertindak sebagai orang yang ditunjuk menjadi perwakilan di acara _online_ atau *offline*. Representasi proyek mungkin selanjutnya didefinisikan dan diklarifikasi oleh pengelola proyek.

## Penegakan

Kejadian perilaku kasar, pelecehan, atau tidak dapat diterima yang terjadi dapat dilaporkan kepada tim inti proyek di timhidrokit@gmail.com. Semua keluhan akan ditinjau dan diselidiki dan akan menghasilkan tanggapan yang dianggap perlu dan sesuai dengan keadaan. Tim inti proyek berkewajiban menjaga kerahasiaan pelapor berkenaan dengan pelapor suatu insiden. 

Rincian lebih lanjut tentang kebijakan penegakan khusus akan dipublikasikan secara terpisah. Pengelola proyek yang tidak mengikuti atau melaksanakan Kode Etik dengan itikad baik mungkin akan menghadapi dampak sementara atau permanen seperti yang ditentukan oleh para anggota lain dari pimpinan proyek.

## Atribut

Kode Etik ini diadaptasi dari [Contributor Covenant](https://www.contributor-covenant.org), versi 1.4, tersedia di [https://www.contributor-covenant.org/version/1/4/code-of-conduct.html](https://www.contributor-covenant.org/version/1/4/code-of-conduct.html).

==> hidrokit-0.4.0.tar.gz: hidrokit-0.4.0/CODE_OF_CONDUCT.md <==
# Kode Etik Contributor Covenant

## Janji Kami

Sesuai minat kami untuk membuat lingkungan yang terbuka dan ramah, kami sebagai kontributor dan pengelola berjanji untuk membuat partisipasi dalam proyek kami dan komunitas kami bebas dari pelecehan untuk semua orang, tanpa memandang usia, ukuran tubuh, disabilitas, kelompok etnis, identitas gender dan ekspresinya, tingkat pengalaman, pendidikan, status sosial ekonomi, kewarganegaraan, penampilan pribadi, ras, agama, atau identitas dan orientasi seksual.

## Standar Kami

Kejadian perilaku yang berkontribusi untuk menciptakan sebuah lingkungan yang positif meliputi:
* Memakai bahasa yang ramah dan inklusif.
* Menghormati sudut pandang dan pengalaman yang berbeda.
* Menerima kritik konstruktif dengan baik.
* Fokus terhadap apa yang terbaik bagi komunitas.
* Menunjukkan empati kepada anggota komunitas yang lain.

Contoh perilaku yang tidak dapat diterima oleh partisipan meliputi:
* Penggunaan bahasa atau citra seksual dan perhatian seksual yang tidak diinginkan.
* _Trolling_, komentar menghina, dan serangan terhadap individual atau pandangan politik.
* Pelecahan umum atau pribadi.
* Menerbitkan informasi pribadi orang lain, seperti alamat fisik atau elektronik, tanpa izin.
* Perilaku lain yang dapat dianggap tidak sesuai dalam lingkungan profesional.

## Tanggung Jawab Kami

Pengelola proyek bertanggung jawab untuk mengklarifikasi standar perilaku yang dapat diterima dan diharapkan untuk melakukan tindakan korektif yang tepat dan adil dalam menanggapi kasus perilaku yang tidak dapat diterima.

Pengelola proyek mempunyai hak dan tanggung jawab untuk menghapus, mengubah, atau menolak komentar, _commit_, kode, suntingan wiki, masalah, dan kontribusi lainnya yang tidak sesuai dengan Kode Etik ini, atau untuk melarang sementara atau secara permanen kontributor untuk perilaku lain yang mereka anggap tidak tepat, mengancam, menyinggung, atau berbahaya.

## Cakupan

Kode Etik ini berlaku baik di dalam proyek maupun di ruang publik ketika seseorang mewakili proyek atau komunitasnya. Contoh dari mewakili sebuah proyek atau komunitas termasuk menggunakan alamat email resmi proyek, posting melalui akun media sosial resmi, atau bertindak sebagai orang yang ditunjuk menjadi perwakilan di acara _online_ atau *offline*. Representasi proyek mungkin selanjutnya didefinisikan dan diklarifikasi oleh pengelola proyek.

## Penegakan

Kejadian perilaku kasar, pelecehan, atau tidak dapat diterima yang terjadi dapat dilaporkan kepada tim inti proyek di hi@taruma.info. Semua keluhan akan ditinjau dan diselidiki dan akan menghasilkan tanggapan yang dianggap perlu dan sesuai dengan keadaan. Tim inti proyek berkewajiban menjaga kerahasiaan pelapor berkenaan dengan pelapor suatu insiden. 

Rincian lebih lanjut tentang kebijakan penegakan khusus akan dipublikasikan secara terpisah. Pengelola proyek yang tidak mengikuti atau melaksanakan Kode Etik dengan itikad baik mungkin akan menghadapi dampak sementara atau permanen seperti yang ditentukan oleh para anggota lain dari pimpinan proyek.

## Atribut

Kode Etik ini diadaptasi dari [Contributor Covenant](https://www.contributor-covenant.org), versi 1.4, tersedia di [https://www.contributor-covenant.org/version/1/4/code-of-conduct.html](https://www.contributor-covenant.org/version/1/4/code-of-conduct.html).
